import { Button, Form } from "react-bootstrap";
import { Controller, useForm } from "react-hook-form";
import { useTranslation } from "react-i18next";
import validator from "validator";
import { addSport, editSport } from "../../api/sport";

type FormData = {
  id: number;
  name: string;
};

function EditSports(props: {
  onSubmit?: Function;
  id?: number;
  name?: string;
}) {
  const {
    control,
    handleSubmit,
    formState: { errors },
  } = useForm<FormData>({
    mode: "onBlur",
  });
  const { t } = useTranslation();

  const onSubmit = async (data: FormData) => {
    if (props.id) {
      const response = await editSport(data);
    } else {
      const response = await addSport(data);
    }
    if (props.onSubmit) {
      props.onSubmit();
    }
  };

  return (
    <Form onSubmit={handleSubmit(onSubmit)}>
      {props.id && (
        <Controller
          name="id"
          control={control}
          defaultValue={props.id}
          render={({ field }) => (
            <div className="mb-2">
              <Form.Label>{t("sports.Id")}</Form.Label>
              <Form.Control disabled type="text" {...field} />
            </div>
          )}
          rules={{
            required: {
              value: true,
              message: t("boatTypeOverview.messages.required", {
                val: t("boatTypeOverview.Id"),
              }),
            },
          }}
        />
      )}
      <Controller
        name="name"
        control={control}
        defaultValue={props.name}
        render={({ field }) => (
          <div className="mb-2">
            <Form.Label>{t("sports.Name")}</Form.Label>
            <Form.Control type="text" {...field} isInvalid={!!errors.name} />
            <Form.Control.Feedback type="invalid">
              {errors.name?.message}
            </Form.Control.Feedback>
          </div>
        )}
        rules={{
          required: {
            value: true,
            message: t("sports.messages.required", {
              val: t("sports.Name"),
            }),
          },
        }}
      />
      <Button type="submit" variant="secondary" className="mt-2 w-100">
        {t(props.id ? "sports.Edit" : "sports.Add")}
      </Button>
    </Form>
  );
}

export default EditSports;
