import React, { useState } from "react";
import { Table, Button } from "react-bootstrap";
import { useTranslation } from "react-i18next";
import { faEdit, faTrashAlt } from "@fortawesome/free-regular-svg-icons";
import { faPlus } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import StaffModal from "../../components/StaffModal";

function BoatManager() {
    const { t } = useTranslation();
    const [editElement, setEditElement] = useState<({ id: number; name: string; status: number; type: number; } | undefined)>(undefined);
    const [deleteElement, setDeleteElement] = useState<({ id: number; name: string; status: number; type: number; } | undefined)>(undefined);
    const [addElement, setAddElement] = useState<({ id: number; name: string; status: number; type: number; } | boolean)>(false);
    return (
        <div className="m-1 h-100">
            <Table responsive striped bordered hover>
                <thead>
                    <tr>
                        <th>{t("boatTypeOverview.Id")}</th>
                        <th>{t("boatTypeOverview.Name")}</th>
                        <th>{t("boatManager.Status")}</th>
                        <th>{t("boatManager.Type")}</th>
                        <th></th>
                    </tr>
                </thead>
                <tbody style={{ overflowY: "scroll", maxHeight: "100px" }}>
                    {
                        [{ id: 1, name: "Das Boot 1", status: 1, type: 1 }, { id: 2, name: "Das Boot 2", status: 1, type: 1 }, { id: 3, name: "Das Boot 3", status: 1, type: 1 }, { id: 4, name: "Das Boot 2", status: 1, type: 1 }, { id: 5, name: "Das Boot 2", status: 1, type: 1 }, { id: 6, name: "Das Boot 2", status: 1, type: 1 }, { id: 7, name: "Das Boot 2", status: 1, type: 1 }, { id: 8, name: "Das Boot 2", status: 1, type: 1 }, { id: 9, name: "Das Boot 2", status: 1, type: 1 }].map(x => (
                            <tr key={x.id}>
                                <td>{x.id}</td>
                                <td>{x.name}</td>
                                <td>{x.status}</td>
                                <td>{x.type}</td>
                                <td>
                                    <div className="d-flex">
                                        <div className="mx-2" onClick={() => { setEditElement(x) }}><FontAwesomeIcon
                                            icon={faEdit}
                                            className="text-secondary clickableIcon"
                                            size="1x" />
                                        </div>
                                        <div className="mx-2" onClick={() => { setDeleteElement(x) }}><FontAwesomeIcon
                                            icon={faTrashAlt}
                                            className="text-danger clickableIcon"
                                            size="1x" />
                                        </div>
                                    </div>
                                </td>
                            </tr>
                        ))
                    }
                </tbody>
            </Table>
            <div className="d-flex px-2 py-1 justify-content-end bg-white border-top" style={{ position: "sticky", right: "5px", bottom: "0", zIndex: 3 }}>
                <Button onClick={() => { setAddElement(true) }} variant="secondary"><FontAwesomeIcon icon={faPlus} className="text-white me-2" />{t("boatTypeOverview.addBoatType")}</Button>
            </div>
            <StaffModal header={t("boatTypeOverview.addBoatType")} show={!!addElement} successText={t("boatTypeOverview.Add")} onHide={() => { setAddElement(false) }} onSuccess={() => { setAddElement(false) }}>
                {/* <EditBoatTypeForm boatTypename={""} seats={1} sport={editElement?.sport}></EditBoatTypeForm> */}
            </StaffModal>
            <StaffModal header={t("boatTypeOverview.EditBoatType")} successText={t("boatTypeOverview.Edit")} show={!!editElement} onHide={() => { setEditElement(undefined) }} onSuccess={() => { setEditElement(undefined) }}>
                {/* <EditBoatTypeForm id={editElement?.id} boatTypename={editElement?.name} seats={editElement?.seats} sport={editElement?.sport}></EditBoatTypeForm> */}
            </StaffModal>
            <StaffModal header={t("boatTypeOverview.DeleteBoatType")} hideColor="secondary" successText={t("boatTypeOverview.Delete")} successColor="danger" show={!!deleteElement} onHide={() => { setDeleteElement(undefined) }} onSuccess={() => { setDeleteElement(undefined) }}>
                <span>{t("boatTypeOverview.messages.DeleteText", { val: deleteElement?.name })}</span>
            </StaffModal>
        </div>
    )
}

export default BoatManager;
